@@ -2,6 +2,7 @@
     This file is part of the MTP KIOD module, part of the KDE project.
 
     SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,11 +12,11 @@
 #include <QDBusConnection>
 
 #include <Solid/Device>
-#include <Solid/GenericInterface>
 #include <Solid/DeviceNotifier>
+#include <Solid/GenericInterface>
 
-#include "mtpstorage.h"
 #include "kiod_kmtpd_debug.h"
+#include "mtpstorage.h"
 
 // D-Bus adaptors
 #include "deviceadaptor.h"
@@ -28,13 +29,13 @@
  * @param device The LIBMTP_mtpdevice_t pointer to cache
  * @param udi The UDI of the new device to cache
  */
-MTPDevice::MTPDevice(const QString &dbusObjectPath, LIBMTP_mtpdevice_t *device, LIBMTP_raw_device_t *rawdevice, const QString &udi, qint32 timeout, QObject *parent)
-    : QObject(parent),
-      m_dbusObjectName(dbusObjectPath),
-      m_timeout(timeout),
-      m_mtpdevice(device),
-      m_rawdevice(*rawdevice),
-      m_udi(udi)
+MTPDevice::MTPDevice(const QString &dbusObjectPath, LIBMTP_mtpdevice_t *device, LIBMTP_raw_device_t *rawdevice, const QString &udi, QObject *parent)
+    : QObject(parent)
+    , m_dbusObjectName(dbusObjectPath)
+    , m_mtpdevice(device)
+    , m_rawdevice(*rawdevice)
+    , m_udi(udi)
+    , m_devicesUpdated(true)
 {
     const char *deviceName = LIBMTP_Get_Friendlyname(device);
     const char *deviceModel = LIBMTP_Get_Modelname(device);
@@ -46,7 +47,7 @@ MTPDevice::MTPDevice(const QString &dbusObjectPath, LIBMTP_mtpdevice_t *device,
         m_friendlyName = QString::fromUtf8(deviceName);
     }
 
-    qCDebug(LOG_KIOD_KMTPD) << "Created device " << m_friendlyName << "  with udi=" << udi << " and timeout " << timeout;
+    qCDebug(LOG_KIOD_KMTPD) << "Created device " << m_friendlyName << "  with udi=" << udi;
 
     new DeviceAdaptor(this);
     QDBusConnection::sessionBus().registerObject(m_dbusObjectName, this);
@@ -63,6 +64,16 @@ MTPDevice::~MTPDevice()
     LIBMTP_Release_Device(m_mtpdevice);
 }
 
+void MTPDevice::setDevicesUpdatedStatus(bool value)
+{
+    m_devicesUpdated = value;
+}
+
+bool MTPDevice::devicesUpdated() const
+{
+    return m_devicesUpdated;
+}
+
 LIBMTP_mtpdevice_t *MTPDevice::getDevice()
 {
     return m_mtpdevice;
@@ -93,19 +104,30 @@ int MTPDevice::setFriendlyName(const QString &friendlyName)
     if (!result) {
         m_friendlyName = friendlyName;
         Q_EMIT friendlyNameChanged(m_friendlyName);
-
     }
     return result;
 }
 
-QList<QDBusObjectPath> MTPDevice::listStorages() const
+QList<QDBusObjectPath> MTPDevice::listStorages()
 {
     QList<QDBusObjectPath> list;
     list.reserve(m_storages.count());
     for (const MTPStorage *storage : m_storages) {
         list.append(QDBusObjectPath(storage->dbusObjectPath()));
     }
+
+    // New storages have been collected. No new changes anymore.
+    setDevicesUpdatedStatus(false);
+
     return list;
 }
 
+QUrl MTPDevice::url() const
+{
+    QUrl friendlyUrl;
+    friendlyUrl.setScheme(QStringLiteral("mtp"));
+    friendlyUrl.setPath(QLatin1Char('/') + friendlyName());
+    return friendlyUrl;
+}
+
 #include "moc_mtpdevice.cpp"
